@@ -5,7 +5,7 @@ class Auth(DapiRequest):
     def exchangeToken(self, access_code, connection_id):
         '''
         Exchange connect access code for an acccess Token.
-        (`HTTP docs <https://docs.dapi.co/docs/exchange-token>`__)
+        (`HTTP docs <https://docs.dapi.com/docs/exchange-token>`__)
 
         :param  str     access_code:     From the connect JS response after the user logs in
 
@@ -23,7 +23,7 @@ class Auth(DapiRequest):
     def delinkUser(self, access_token, user_secret):
         '''
         Unlink or remove a user from Dapi
-        (`HTTP docs <https://docs.dapi.co/docs/delink>`__)
+        (`HTTP docs <https://docs.dapi.com/docs/delink>`__)
 
         :param  str     access_token:    From the exchangeToken method.
 
